@@ -33,16 +33,16 @@ class Disabilitas:
 
     def todict(self) -> Dict[str, str]:
         return {
-            "1": "1" if self.tunanetra else "2",
-            "2": "1" if self.tunarungu else "2",
-            "3": "1" if self.tunawicara else "2",
-            "4": "1" if self.tunarungu_wicara else "2",
-            "5": "1" if self.tunadaksa else "2",
-            "6": "1" if self.tunagrahita else "2",
-            "7": "1" if self.tunalaras else "2",
-            "8": "1" if self.cacat_eks_kusta else "2",
-            "9": "1" if self.cacat_ganda else "2",
-            "10": "1" if self.dipasung else "2",
+            "1": self.tunanetra.value,
+            "2": self.tunarungu.value,
+            "3": self.tunawicara.value,
+            "4": self.tunarungu_wicara.value,
+            "5": self.tunadaksa.value,
+            "6": self.tunagrahita.value,
+            "7": self.tunalaras.value,
+            "8": self.cacat_eks_kusta.value,
+            "9": self.cacat_ganda.value,
+            "10": self.dipasung.value,
             "11": "2",
             "12": "2",
             "13": "2",
